package cz.boosik.boosCooldown;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import org.bukkit.entity.Player;

import util.boosChat;

/**
 * Tda obsahuje veker metody potebn k zen cooldown asova. Spoutn,
 * ukonovn, zjiovn zda je cooldown asova ji aktivn.
 * 
 * @author Jakub Kol
 * 
 */
public class BoosCoolDownManager {
	/**
	 * Metoda ukonuje specifikovan cooldown asova pro specifikovanho hre.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 */
	static void cancelCooldown(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		BoosConfigManager.getConfusers().set(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".cooldown." + pre2, null);
	}

	/**
	 * Metoda vrac hodnotu boolean na zklad toho, jestli m specifikovan
	 * pkaz aktivn cooldown asova.
	 * 
	 * @param player
	 *            specifikovan hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 * @param coolDownSeconds
	 *            cooldown doba v sekundch, nastaven pro regexCommand v
	 *            konfiguraci
	 * @return true pokud je pkaz na cooldown asovai, jinak false
	 */
	static boolean cd(Player player, String regexCommand,
			String originalCommand, int coolDownSeconds) {
		Date lastTime = getTime(player, regexCommand);
		String link = BoosConfigManager.getLink(regexCommand);
		if (lastTime == null) {
			if (link == null) {
				setTime(player, regexCommand);
			} else {
				List<String> linkGroup = BoosConfigManager.getLinkList(link);
				for (String a : linkGroup) {
					setTime(player, a);
				}
			}
			return false;
		} else {
			Calendar calcurrTime = Calendar.getInstance();
			calcurrTime.setTime(getCurrTime());
			Calendar callastTime = Calendar.getInstance();
			callastTime.setTime(lastTime);
			long secondsBetween = secondsBetween(callastTime, calcurrTime);
			long waitSeconds = coolDownSeconds - secondsBetween;
			long waitMinutes = Math.round(waitSeconds / 60) + 1;
			long waitHours = Math.round(waitMinutes / 60) + 1;
			if (secondsBetween > coolDownSeconds) {
				if (link == null) {
					setTime(player, regexCommand);
				} else {
					List<String> linkGroup = BoosConfigManager
							.getLinkList(link);
					for (String a : linkGroup) {
						setTime(player, a);
					}
				}
				return false;
			} else {
				String msg = BoosConfigManager.getCoolDownMessage();
				msg = msg.replaceAll("&command&", originalCommand);
				if (waitSeconds >= 60 && 3600 >= waitSeconds) {
					msg = msg.replaceAll("&seconds&",
							Long.toString(waitMinutes));
					msg = msg.replaceAll("&unit&",
							BoosConfigManager.getUnitMinutesMessage());
				} else if (waitMinutes >= 60) {
					msg = msg.replaceAll("&seconds&", Long.toString(waitHours));
					msg = msg.replaceAll("&unit&",
							BoosConfigManager.getUnitHoursMessage());
				} else {
					String secs = Long.toString(waitSeconds);
					if (secs.equals("0")) {
						secs = "1";
					}
					msg = msg.replaceAll("&seconds&", secs);
					msg = msg.replaceAll("&unit&",
							BoosConfigManager.getUnitSecondsMessage());
				}
				boosChat.sendMessageToPlayer(player, msg);
				return true;
			}
		}
	}

	/**
	 * Metoda kontroluje, jestli hr nedisponuje oprvnnmi, kter obchzej
	 * cooldown asovae. Pokud tmito oprvnnmi hr disponuje, pak metoda
	 * vrac false. Pokud hr nedisponuje tmito oprvnnmi, vrac hodnotu
	 * vrcenou metodou cd();.
	 * 
	 * @param player
	 *            specifikovan hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 * @param time
	 *            cooldown doba v sekundch, nastaven pro regexCommand v
	 *            konfiguraci
	 * @return false pokud hr disponuje oprvnnmi, jinak hodnotu vrcenou
	 *         metodou cd();.
	 */
	static boolean coolDown(Player player, String regexCommand,
			String originalCommand, int time) {
		regexCommand = regexCommand.toLowerCase();
		if (time > 0
				&& !player.hasPermission("booscooldowns.nocooldown")
				&& !player.hasPermission("booscooldowns.nocooldown."
						+ originalCommand)) {
			return cd(player, regexCommand, originalCommand, time);
		}
		return false;
	}

	/**
	 * Metoda vrac souasn pesn datum a as.
	 * 
	 * @return souasn as a datum
	 */
	static Date getCurrTime() {
		String currTime = "";
		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy HH:mm:ss");
		currTime = sdf.format(cal.getTime());
		Date time = null;

		try {
			time = sdf.parse(currTime);
			return time;
		} catch (ParseException e) {
			return null;
		}
	}

	/**
	 * Metoda vrac datum a as, kdy hr naposledy pouil dan pkaz.
	 * 
	 * @param player
	 *            specifikovan hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 * @return datum a as kdy hr naposledy pouil dan pkaz
	 */
	static Date getTime(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		String confTime = "";
		confTime = BoosConfigManager.getConfusers().getString(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".cooldown." + pre2, null);

		if (confTime != null && !confTime.equals("")) {
			SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy HH:mm:ss");
			Date lastDate = null;

			try {
				lastDate = sdf.parse(confTime);
				return lastDate;
			} catch (ParseException e) {
				return null;
			}
		}
		return null;
	}

	/**
	 * Metoda vrac hodnotu boolean na zklad toho, jestli m specifikovan
	 * pkaz aktivn cooldown asova.
	 * 
	 * @param player
	 *            specifikovan hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 * @param time
	 *            cooldown doba v sekundch, nastaven pro regexCommand v
	 *            konfiguraci
	 * @return false pokud m pkaz aktivn cooldown asova, jinak false
	 */
	static boolean checkCoolDownOK(Player player, String regexCommand,
			String originalCommand, int time) {
		regexCommand = regexCommand.toLowerCase();
		if (time > 0) {
			Date lastTime = getTime(player, regexCommand);
			if (lastTime == null) {
				return true;
			} else {
				Calendar calcurrTime = Calendar.getInstance();
				calcurrTime.setTime(getCurrTime());
				Calendar callastTime = Calendar.getInstance();
				callastTime.setTime(lastTime);
				long secondsBetween = secondsBetween(callastTime, calcurrTime);
				long waitSeconds = time - secondsBetween;
				long waitMinutes = Math.round(waitSeconds / 60) + 1;
				long waitHours = Math.round(waitMinutes / 60) + 1;
				if (secondsBetween > time) {
					return true;
				} else {
					String msg = BoosConfigManager.getCoolDownMessage();
					msg = msg.replaceAll("&command&", originalCommand);
					if (waitSeconds >= 60 && 3600 >= waitSeconds) {
						msg = msg.replaceAll("&seconds&",
								Long.toString(waitMinutes));
						msg = msg.replaceAll("&unit&",
								BoosConfigManager.getUnitMinutesMessage());
					} else if (waitMinutes >= 60) {
						msg = msg.replaceAll("&seconds&",
								Long.toString(waitHours));
						msg = msg.replaceAll("&unit&",
								BoosConfigManager.getUnitHoursMessage());
					} else {
						msg = msg.replaceAll("&seconds&",
								Long.toString(waitSeconds));
						msg = msg.replaceAll("&unit&",
								BoosConfigManager.getUnitSecondsMessage());
					}
					boosChat.sendMessageToPlayer(player, msg);
					return false;
				}
			}
		}
		return true;
	}

	/**
	 * Metoda vrac hodnotu rozdlu v sekundch mezi dvmi hodnotami datumu a
	 * asu.
	 * 
	 * @param startDate
	 * @param endDate
	 * @return rozdl v sekundch mezi startDate a endDate
	 */
	static long secondsBetween(Calendar startDate, Calendar endDate) {
		long secondsBetween = 0;

		while (startDate.before(endDate)) {
			startDate.add(Calendar.SECOND, 1);
			secondsBetween++;
		}
		return secondsBetween;
	}

	/**
	 * Metoda ukld do databze datum a as kdy hr naposledy pouil dan
	 * pkaz.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfigurace vyhovujc originlnmu pkazu
	 */
	static void setTime(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		String currTime = "";
		Calendar cal = Calendar.getInstance();
		SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy HH:mm:ss");
		currTime = sdf.format(cal.getTime());
		BoosConfigManager.getConfusers().set(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".cooldown." + pre2, currTime);
	}

	/**
	 * Metoda spout veker cooldown asovae pro specifickho hre.
	 * 
	 * @param player
	 *            specifick hr
	 * @param message
	 */
	public static void startAllCooldowns(Player player, String message) {
		for (String a : BoosConfigManager.getCooldowns(player)) {
			int cooldownTime = BoosConfigManager.getCoolDown(a, player);
			coolDown(player, a, message, cooldownTime);
		}

	}

}
