package cz.boosik.boosCooldown;

import org.bukkit.entity.Player;

import util.boosChat;

/**
 * Tda obsahuje veker metody potebn k zen limit.
 * 
 * @author Jakub Kol
 * 
 */
public class BoosLimitManager {
	/**
	 * Metoda kontroluje zda je mon pout pkaz, nebo zda je pkaz ji
	 * zablokovan.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 * @param limit
	 *            limit nastaven pro regexCommand
	 * @return false pokud pkaz je mon pout, true pokud pkaz nen mon
	 *         pout
	 */
	static boolean blocked(Player player, String regexCommand,
			String originalCommand, int limit) {
		int uses = getUses(player, regexCommand);
		if (player.hasPermission("booscooldowns.nolimit")
				|| player.hasPermission("booscooldowns.nolimit."
						+ originalCommand)) {
		} else {
			if (limit == -1) {
				return false;
			} else if (limit <= uses) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Metoda vrac hodnotu, kter je urena tm, kolikrt ji hr pouil
	 * specifikovan pkaz.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @return hodnota pedstavujci poet pouit specifikovanho pkazu
	 */
	static int getUses(Player player, String regexCommand) {
		int regexCommand2 = regexCommand.toLowerCase().hashCode();
		int uses = 0;
		uses = BoosConfigManager.getConfusers().getInt(
				"users." + player.getName().toLowerCase().hashCode() + ".uses."
						+ regexCommand2, uses);
		return uses;
	}

	/**
	 * Metoda nastavuje poet pouit pkazu o jedna vt po kadm pouit
	 * pkazu hrem. Nasteven hodnoty probh jen pro pkazy, kter jsou
	 * definovny v konfiguraci.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 */
	static void setUses(Player player, String regexCommand,
			String originalCommand) {
		if (BoosConfigManager.getLimitsEnabled()) {
			if (BoosConfigManager.getCommands(player).contains(regexCommand)) {
				int regexCommand2 = regexCommand.toLowerCase().hashCode();
				int uses = getUses(player, regexCommand);
				uses = uses + 1;
				try {
					BoosConfigManager.getConfusers().set(
							"users."
									+ player.getName().toLowerCase().hashCode()
									+ ".uses." + regexCommand2, uses);
				} catch (IllegalArgumentException e) {
					BoosCoolDown
							.getLog()
							.warning(
									"Player "
											+ player.getName()
											+ " used empty command and caused this error!");
				}
			} else {
				return;
			}
		}
	}

	/**
	 * Metoda odesl hri zprvu o limitovanm pkazu, hodnotu tohoto limitu
	 * a kolikrt je jet mon limitovan pkaz pout.
	 * 
	 * @param send
	 *            hr ktermu bude odesln seznam
	 * @param comm
	 *            pkaz o kterm si hr vydal informace
	 * @param lim
	 *            hodnota limitu na pkazu
	 */
	static void getLimitListMessages(Player send, String comm, int lim) {
		if (lim != -1) {
			int uses = getUses(send, comm);
			String message = BoosConfigManager.getLimitListMessage();
			int num = lim - uses;
			if (num < 0) {
				num = 0;
			}
			message = BoosConfigManager.getLimitListMessage();
			message = message.replaceAll("&command&", comm);
			message = message.replaceAll("&limit&", String.valueOf(lim));
			message = message.replaceAll("&times&", String.valueOf(num));
			boosChat.sendMessageToPlayer(send, message);
		}
	}

}
