package cz.boosik.boosCooldown;

import java.util.Iterator;
import java.util.Timer;
import java.util.concurrent.ConcurrentHashMap;

import org.bukkit.Location;
import org.bukkit.entity.Player;
import org.bukkit.potion.PotionEffectType;

import util.boosChat;

/**
 * Tda obsahuje veker metody potebn k zen warmup asova. Spoutn,
 * ukonovn a zjiovn zda je warmup asova ji aktivn.
 * 
 * @author Jakub Kol
 * 
 */
public class BoosWarmUpManager {

	private static ConcurrentHashMap<String, BoosWarmUpTimer> playercommands = new ConcurrentHashMap<String, BoosWarmUpTimer>();
	private static ConcurrentHashMap<Player, Location> playerloc = new ConcurrentHashMap<Player, Location>();
	private static ConcurrentHashMap<Player, String> playerworld = new ConcurrentHashMap<Player, String>();

	private static Timer scheduler;

	/**
	 * Metoda aplikuje na hre magick efekt na dobu urenou parametrem
	 * warmUpSeconds.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @param warmUpSeconds
	 *            doba warmup v sekundch, nastaven pro regexCommand v
	 *            konfiguraci
	 */
	static void applyPotionEffect(Player player, String regexCommand,
			int warmUpSeconds) {
		String potion = BoosConfigManager.getPotionEffect(regexCommand, player);
		if (potion.equals("")) {
			return;
		}
		int potionStrength = BoosConfigManager.getPotionEffectStrength(
				regexCommand, player);
		if (potionStrength == 0) {
			return;
		}
		PotionEffectType effect = PotionEffectType.getByName(potion);
		player.addPotionEffect(
				effect.createEffect(warmUpSeconds * 40, potionStrength - 1),
				true);
	}

	/**
	 * Metoda stornuje veker probhajc warmup asovae specifickho hre.
	 * 
	 * @param player
	 *            specifick hr
	 */
	public static void cancelWarmUps(Player player) {
		Iterator<String> iter = playercommands.keySet().iterator();
		while (iter.hasNext()) {
			if (iter.next().startsWith(player.getName() + "@")) {
				killTimer(player);
				iter.remove();
			}
		}
	}

	/**
	 * Metoda pro specifickho hre vymae uloenou pozici a svt.
	 * 
	 * @param player
	 *            specifick hr
	 */
	public static void clearLocWorld(Player player) {
		BoosWarmUpManager.playerloc.remove(player);
		BoosWarmUpManager.playerworld.remove(player);
	}

	/**
	 * Metoda vrac boolean hodnotu v zvislosti na tom jestli specifikovan
	 * hr m aktivn warmup asovae nebo ne.
	 * 
	 * @param player
	 *            specifick hr
	 * @return true pokud hr m aktivn warmup asovae, jinak false
	 */
	public static boolean hasWarmUps(Player player) {
		for (String key : playercommands.keySet()) {
			if (key.startsWith(player.getName() + "@")) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Metoda zjiuje, jestli je dan warmup asova oznaen jako ji probhl
	 * nebo ne.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @return true pokud je warmup asova oznaen jako ji probhl, jinak
	 *         false
	 */
	static boolean checkWarmUpOK(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		int ok = 0;
		ok = BoosConfigManager.getConfusers().getInt(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".warmup." + pre2, ok);
		if (ok == 1) {
			return true;
		}
		return false;
	}

	/**
	 * Metoda vrac boolean hodnotu na zklad toho jestli je pro specifikovan
	 * pkaz specifikovanho hre aktivn warmup asova.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @return true pokud je warmup asova aktivn, jinak false
	 */
	static boolean isWarmUpProcess(Player player, String regexCommand) {
		regexCommand = regexCommand.toLowerCase();
		if (playercommands.containsKey(player.getName() + "@" + regexCommand)) {
			return true;
		}
		return false;
	}

	/**
	 * Metoda odstran vechny asovae specifikovanho hre
	 * 
	 * @param player
	 *            specifick hr
	 */
	static void killTimer(Player player) {
		for (String key : playercommands.keySet()) {
			if (key.startsWith(player.getName() + "@")) {
				playercommands.get(key).cancel();
			}
		}
	}

	/**
	 * Metoda odstran asovae na specifikovanm pkazu specifikovanho hre
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 */
	static void removeWarmUp(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		BoosConfigManager.getConfusers().set(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".warmup." + pre2, null);
	}

	/**
	 * Metoda odstran ukonen asovae na specifikovanm pkazu
	 * specifikovanho hre
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 */
	static void removeWarmUpOK(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		BoosConfigManager.getConfusers().set(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".warmup." + pre2, null);
	}

	/**
	 * Metoda odstrauje dan etzec z Hashmapy
	 * 
	 * @param tag
	 *            etzec, kter se m odstranit z Hasmapy
	 */
	static void removeWarmUpProcess(String tag) {
		BoosWarmUpManager.playercommands.remove(tag);
	}

	/**
	 * Metoda oznauje warmup asova specifikovanho pkazu specifikovanho
	 * hre jako ji ukonen.
	 * 
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 */
	static void setWarmUpOK(Player player, String regexCommand) {
		int pre2 = regexCommand.toLowerCase().hashCode();
		BoosConfigManager.getConfusers().set(
				"users." + player.getName().toLowerCase().hashCode()
						+ ".warmup." + pre2, 1);
	}

	/**
	 * Metoda spout warmup asova na zklad parametr pomoc Timer(). Pokud
	 * je ji warmup aktivn, odele hri zprvu kter ho o tom informuje.
	 * 
	 * @param bCoolDown
	 *            instance tdy BoosCooldown
	 * @param player
	 *            specifick hr
	 * @param regexCommand
	 *            pkaz z konfiguranho souboru, kter vyhovuje originlnmu
	 *            pkazu
	 * @param originalCommand
	 *            originln pkaz pouit hrem
	 * @param warmUpSeconds
	 *            warmup doba nastaven pro pkaz v sekundch
	 */
	static void startWarmUp(BoosCoolDown bCoolDown, Player player,
			String regexCommand, String originalCommand, int warmUpSeconds) {
		regexCommand = regexCommand.toLowerCase();
		long warmUpMinutes = Math.round(warmUpSeconds / 60);
		long warmUpHours = Math.round(warmUpMinutes / 60);
		if (!isWarmUpProcess(player, regexCommand)) {
			BoosWarmUpManager.removeWarmUpOK(player, regexCommand);
			String msg = BoosConfigManager.getWarmUpMessage();
			msg = msg.replaceAll("&command&", originalCommand);
			if (warmUpSeconds >= 60 && 3600 >= warmUpSeconds) {
				msg = msg.replaceAll("&seconds&", Long.toString(warmUpMinutes));
				msg = msg.replaceAll("&unit&",
						BoosConfigManager.getUnitMinutesMessage());
			} else if (warmUpMinutes >= 60) {
				msg = msg.replaceAll("&seconds&", Long.toString(warmUpHours));
				msg = msg.replaceAll("&unit&",
						BoosConfigManager.getUnitHoursMessage());
			} else {
				msg = msg.replaceAll("&seconds&", Long.toString(warmUpSeconds));
				msg = msg.replaceAll("&unit&",
						BoosConfigManager.getUnitSecondsMessage());
			}
			boosChat.sendMessageToPlayer(player, msg);

			scheduler = new Timer();
			BoosWarmUpTimer scheduleMe = new BoosWarmUpTimer(bCoolDown,
					scheduler, player, regexCommand, originalCommand);
			playercommands.put(player.getName() + "@" + regexCommand,
					scheduleMe);
			scheduler.schedule(scheduleMe, warmUpSeconds * 1000);
			applyPotionEffect(player, regexCommand, warmUpSeconds);
		} else {
			String msg = BoosConfigManager.getWarmUpAlreadyStartedMessage();
			msg = msg.replaceAll("&command&", originalCommand);
			boosChat.sendMessageToPlayer(player, msg);
		}
	}

	/**
	 * @return
	 */
	public static ConcurrentHashMap<Player, String> getPlayerworld() {
		return playerworld;
	}

	/**
	 * @return
	 */
	public static ConcurrentHashMap<Player, Location> getPlayerloc() {
		return playerloc;
	}
}
